@@ -25,11 +25,18 @@
 "tgp.plot.parts.1d" <-
 function(parts,lwd=1)
 {
-	j <- 3
-	for(i in seq(2,dim(parts)[1],2)) {
-		if(i == dim(parts)[1]-2) { break; }
-		abline(v=parts[i,1], col=j, lty=j,lwd=lwd);
-		j <- j + 1
-	}
+  j <- 3
+  if(is.null(dim(parts))) dp <- length(parts)
+  else {
+    dp <- dim(parts)[1]
+    parts <- parts[,1]
+  }
+  is <- seq(2, dp, by=4)
+  m <- max(parts[is])
+  for(i in is) {
+    if(parts[i] == m) next;
+    abline(v=parts[i], col=j, lty=j, lwd=lwd);
+    j <- j + 1
+  }
 }
 
